@@ -14,11 +14,21 @@ import os, subprocess
 def coffee(app):
     @app.before_request
     def _render_coffee():
-        try:
-            static_dir = app.root_path + app.static_url_path
-        except AttributeError, e:    
-            static_dir = app.root_path + app.static_path # < version 0.7
-        
+
+        if not hasattr(app, 'static_url_path'):
+            from warnings import warn
+            warn(DeprecationWarning('static_path is called '
+                                    'static_url_path since Flask 0.7'),
+                                    stacklevel=2)
+
+            static_url_path = app.static_path
+
+        else:
+            static_url_path = app.static_url_path
+
+        static_dir = app.root_path + app.static_url_path
+
+            
         coffee_paths = []
         for path, subdirs, filenames in os.walk(static_dir):
             coffee_paths.extend([
